<template>
  <div class="power_box">
    <My-bread
      :list="[
        `${$t('userManage.userManage')}`,
        `${$t('userManage.authorityManage')}`,
      ]"
    ></My-bread>
    <el-divider />
    <div class="power_quire">
      <el-form ref="form" :model="form" label-width="100px" :inline="true">
        <el-form-item :label="$t('common.username')">
          <el-input v-model="form.name"></el-input>
        </el-form-item>
        <el-form-item>
          <el-button icon="el-icon-search" type="primary" plain>{{
            $t('common.iquery')
          }}</el-button>
        </el-form-item>
      </el-form>
    </div>
    <div class="table_box">
      <el-table :data="tableData" border style="width: 100%">
        <el-table-column
          align="center"
          type="index"
          :label="$t('operatManage.ELM.index')"
          width="70px"
        />
        <el-table-column
          prop="date"
          align="center"
          :label="$t('userManage.userInfoObj.username')"
        >
        </el-table-column>
        <el-table-column
          prop="name"
          align="center"
          :label="$t('userManage.userInfoObj.affiliatedUnit')"
        >
        </el-table-column>
        <el-table-column
          prop="province"
          align="center"
          :label="$t('userManage.userInfoObj.mobileNumber')"
        >
        </el-table-column>
        <el-table-column
          prop="city"
          align="center"
          :label="$t('userManage.userInfoObj.post')"
        >
        </el-table-column>
        <el-table-column
          prop="address"
          align="center"
          :label="$t('userManage.userInfoObj.userstate')"
        >
        </el-table-column>
        <el-table-column
          prop="zip"
          align="center"
          :label="$t('userManage.userInfoObj.addtime')"
        >
        </el-table-column>
        <el-table-column
          fixed="right"
          :label="$t('common.operate')"
          width="170px"
        >
          <template slot-scope="scope">
            <el-button
              @click="handleClick(scope.row)"
              type="warning"
              size="small"
              >{{ $t('common.edit') }}</el-button
            >
            <el-button type="danger" size="small">{{
              $t('common.delete')
            }}</el-button>
          </template>
        </el-table-column>
      </el-table>
    </div>
    <div class="pagination_box">
      <el-pagination
        @size-change="handleSizeChange"
        @current-change="handleCurrentChange"
        :current-page="currentPage"
        :page-sizes="[10, 20, 30, 40]"
        :page-size="10"
        layout="total, sizes, prev, pager, next, jumper"
        :total="9"
      >
      </el-pagination>
    </div>

    <el-dialog
      :title="dialogTitle"
      :visible.sync="isTransfer"
      width="800px"
      append-to-body
    >
      <el-tree
        :data="data"
        show-checkbox
        node-key="id"
        :default-expanded-keys="[2, 3]"
        :default-checked-keys="[5]"
        :props="defaultProps"
      >
      </el-tree>
      <el-button type="primary" size="small">{{
        $t('common.confirm')
      }}</el-button>
      <el-button type="info" size="small">{{ $t('common.close') }}</el-button>
    </el-dialog>
  </div>
</template>

<script>
import MyBread from '../../components/MyBread.vue';
export default {
  components: { MyBread },
  data() {
    return {
      form: {},
      isTransfer: false,
      dialogTitle: '',
      data: [
        {
          id: 1,
          label: '一级 1',
          children: [
            {
              id: 4,
              label: '二级 1-1',
              children: [
                {
                  id: 9,
                  label: '三级 1-1-1',
                },
                {
                  id: 10,
                  label: '三级 1-1-2',
                },
              ],
            },
          ],
        },
        {
          id: 2,
          label: '一级 2',
          children: [
            {
              id: 5,
              label: '二级 2-1',
            },
            {
              id: 6,
              label: '二级 2-2',
            },
          ],
        },
        {
          id: 3,
          label: '一级 3',
          children: [
            {
              id: 7,
              label: '二级 3-1',
            },
            {
              id: 8,
              label: '二级 3-2',
            },
          ],
        },
      ],
      tableData: [
        {
          date: '2016-05-02',
          name: '王小虎',
          province: '上海',
          city: '普陀区',
          address: '上海市普陀区金沙江路 1518 弄',
          zip: 200333,
        },
        {
          date: '2016-05-04',
          name: '王小虎',
          province: '上海',
          city: '普陀区',
          address: '上海市普陀区金沙江路 1517 弄',
          zip: 200333,
        },
        {
          date: '2016-05-01',
          name: '王小虎',
          province: '上海',
          city: '普陀区',
          address: '上海市普陀区金沙江路 1519 弄',
          zip: 200333,
        },
        {
          date: '2016-05-03',
          name: '王小虎',
          province: '上海',
          city: '普陀区',
          address: '上海市普陀区金沙江路 1516 弄',
          zip: 200333,
        },
      ],
    };
  },
  defaultProps: {
    children: 'children',
    label: 'label',
  },
  methods: {
    handleClick(row) {
      console.log(row);
      this.dialogTitle = row.name;
      this.isTransfer = true;
    },
  },
};
</script>

<style lang="less" scoped>
.power_box {
  background: rgb(240, 242, 245);
  border-radius: 10px;
  height: 100%;
  padding: 10px;
  box-sizing: border-box;
  .el-input {
    width: 300px;
  }
  .power_quire {
    overflow: auto;
    padding: 8px;
    margin-top: 20px;
    background: #fff;
    border-radius: 5px;
    border: 1px solid rgb(202, 201, 204);
    padding-top: 25px;
    margin-bottom: 20px;
  }
  .table_box {
    height: 68%;
    padding: 10px;
    background: #fff;
    border-radius: 5px;
    border: 1px solid rgb(202, 201, 204);
  }
  .pagination_box {
    margin-top: 20px;
  }
}
</style>
